FUIRefreshText class

Localized labels displayed by FUIRefresh indicators.

Constructors

FUIRefreshText({required String pullToRefresh, required String releaseToRefresh, required String refreshing, required String refreshSuccess, required String refreshFailed, required String pullToLoad, required String releaseToLoad, required String loading, required String loadSuccess, required String loadFailed, required String noMore})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
loadFailed String
final
loading String
final
loadSuccess String
final
noMore String
final
pullToLoad String
final
pullToRefresh String
final
refreshFailed String
final
refreshing String
final
refreshSuccess String
final
releaseToLoad String
final
releaseToRefresh String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

resolve(BuildContext context) FUIRefreshText