FuiAdaptiveSplitScaffold<T> class

Inheritance

Constructors

FuiAdaptiveSplitScaffold({Key? key, required List<FuiSplitItem<T>> items, required T? selectedValue, required ValueChanged<T> onSelected, required Widget detailBuilder(BuildContext context, T value), Widget supplementaryBuilder(BuildContext context, T value)?, Widget? masterHeader, Widget? masterFooter, Widget? emptyDetail, Widget? emptySupplementary, FuiCompactDetailPresentation compactPresentation = FuiCompactDetailPresentation.auto, FuiNavigationBreakpoints breakpoints = const FuiNavigationBreakpoints(), FuiSplitNavigationPlan plan = const FuiSplitNavigationPlan(), String? masterTitle})
const

Properties

breakpoints FuiNavigationBreakpoints
final
compactPresentation FuiCompactDetailPresentation
final
detailBuilder Widget Function(BuildContext context, T value)
final
emptyDetail Widget?
final
emptySupplementary Widget?
final
hashCode int
The hash code for this object.
no setterinherited
items List<FuiSplitItem<T>>
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
masterFooter Widget?
final
masterHeader Widget?
final
masterTitle String?
final
onSelected ValueChanged<T>
final
plan FuiSplitNavigationPlan
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedValue → T?
final
supplementaryBuilder Widget Function(BuildContext context, T value)?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited