FuiNavigation class abstract final

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

canPopSecondaryPane(BuildContext context) bool
closeCurrent(BuildContext context, {bool force = false}) → void
isSecondaryPane(BuildContext context) bool
isSplit(BuildContext context, {FuiNavigationBreakpoints breakpoints = const FuiNavigationBreakpoints()}) bool
openDetail(BuildContext context, {required WidgetBuilder builder, String? title, FuiCompactDetailPresentation compactPresentation = FuiCompactDetailPresentation.auto, FuiNavigationBreakpoints breakpoints = const FuiNavigationBreakpoints(), bool fullscreenDialog = false, bool barrierDismissible = true, bool preferSecondaryPane = true, bool useSafeArea = true}) Future<void>
resolve(BuildContext context, {FuiNavigationBreakpoints breakpoints = const FuiNavigationBreakpoints(), bool enableSplit = false}) FuiNavigationLayout