FuiNavigationBreakpoints class

Annotations

Constructors

FuiNavigationBreakpoints({double railWidth = 720, double extendedRailWidth = 1100, double splitWidth = 900, double splitMinHeight = 600, double splitMinAspectRatio = 1.2})
const

Properties

extendedRailWidth double
final
hashCode int
The hash code for this object.
no setterinherited
railWidth double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
splitMinAspectRatio double
final
splitMinHeight double
final
splitWidth double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(double width, {bool enableSplit = false}) FuiNavigationLayout
resolveForSize(Size size, {bool enableSplit = false}) FuiNavigationLayout
shouldExtendRail(Size size) bool
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited