FuiAccent class
- Annotations
Constructors
- FuiAccent({required Color primary, required Color hover, required Color pressed, required Color soft, required Color subtle})
-
const
- FuiAccent.fromColorScheme(ColorScheme scheme)
-
factory
Properties
Methods
-
applyTo(
FUIPalette palette) → FUIPalette -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited