FuiTheme class abstract final

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

build({required FUIPalette palette, required Brightness brightness}) ThemeData
dark({FuiAccent? accent}) ThemeData
light({FuiAccent? accent}) ThemeData
overlayStyleFor(Brightness brightness) SystemUiOverlayStyle

Constants

pageTransitionsTheme → const PageTransitionsTheme
Page transition policy extracted from the original GXNU Class Tool.
scrollBehavior → const ScrollBehavior