Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- add → const IconData
- apps → const IconData
- appsFilled → const IconData
- autoBrightness → const IconData
- badge → const IconData
- book → const IconData
- bug → const IconData
- building → const IconData
- calendar → const IconData
- calendarAdd → const IconData
- calendarFilled → const IconData
- chart → const IconData
- check → const IconData
- checkmark → const IconData
- checkmarkSmall → const IconData
- chevronDown → const IconData
- chevronLeft → const IconData
- chevronRight → const IconData
- circleFilled → const IconData
- classroom → const IconData
- close → const IconData
- copy → const IconData
- credit → const IconData
- darkMode → const IconData
- delete → const IconData
- empty → const IconData
- error → const IconData
- exam → const IconData
- filter → const IconData
- grade → const IconData
- home → const IconData
- homeFilled → const IconData
- info → const IconData
- lightMode → const IconData
- list → const IconData
- location → const IconData
- lock → const IconData
- login → const IconData
- logout → const IconData
- more → const IconData
- notification → const IconData
- notificationActive → const IconData
- open → const IconData
- palette → const IconData
- password → const IconData
- person → const IconData
- privacy → const IconData
- progress → const IconData
- refresh → const IconData
- save → const IconData
- schedule → const IconData
- school → const IconData
- search → const IconData
- settings → const IconData
- settingsFilled → const IconData
- today → const IconData
- update → const IconData
- visibility → const IconData
- visibilityOff → const IconData
- warning → const IconData