FUIToast class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
error(BuildContext context, {required String message, String? title})
→ void
-
-
errorGlobal({required String message, String? title})
→ void
-
-
info(BuildContext context, {required String message, String? title})
→ void
-
-
infoGlobal({required String message, String? title})
→ void
-
-
show(BuildContext context, {required String message, String? title, FUIToastType type = FUIToastType.info, Duration duration = const Duration(seconds: 2)})
→ void
-
-
showGlobal({required String message, String? title, FUIToastType type = FUIToastType.info, Duration duration = const Duration(seconds: 2)})
→ void
-
-
success(BuildContext context, {required String message, String? title})
→ void
-
-
successGlobal({required String message, String? title})
→ void
-
-
warning(BuildContext context, {required String message, String? title})
→ void
-
-
warningGlobal({required String message, String? title})
→ void
-