FuiSplitNavigationPlan class
- Annotations
Constructors
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- masterWidth → double
-
final
- minDetailWidth → double
-
final
- minSupplementaryWidth → double
-
final
- minThreePaneWidth → double
-
no setter
- placeholder → Widget?
-
final
- placeholderData → FuiSecondaryPlaceholderData
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supplementaryWidth → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited