FuiAccent class

Annotations

Constructors

FuiAccent({required Color primary, required Color hover, required Color pressed, required Color soft, required Color subtle})
const
FuiAccent.fromColorScheme(ColorScheme scheme)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
hover Color
final
pressed Color
final
primary Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
soft Color
final
subtle Color
final

Methods

applyTo(FUIPalette palette) FUIPalette
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited